"use strict";
const path = require("path");
const fs = require("fs");
const gettextParser = require("gettext-parser");
const debug = require("./debug");
let locales = {};
let localesWithoutContext = {};
class NerveLocales {
    static init(app) {
        let localesDir = app.getCfg('localesDir');
        if (localesDir) {
            fs.readdir(localesDir, (err, files) => {
                if (err) {
                    debug.error('Failed read locales');
                }
                else {
                    files.forEach((locale) => {
                        let filePath = path.resolve(app.getCfg('localesDir'), locale, app.getCfg('localesFileName'));
                        fs.readFile(filePath, (err, content) => {
                            if (err) {
                                debug.error(`Failed read locales file: ${filePath}: `, err);
                            }
                            else {
                                const translations = gettextParser.po.parse(content.toString()).translations;
                                locales[locale] = translations;
                                localesWithoutContext[locale] = {};
                                Object.keys(translations)
                                    .forEach((ctx) => {
                                    Object.keys(translations[ctx])
                                        .forEach((msgId) => {
                                        const item = translations[ctx][msgId];
                                        localesWithoutContext[locale][msgId] = item.msgstr[0];
                                    });
                                });
                            }
                        });
                    });
                }
            });
        }
    }
    static getText(message, locale, ctx) {
        let result;
        ctx = ctx || '';
        result = locales[locale] && locales[locale][ctx] && locales[locale][ctx][message] && locales[locale][ctx][message].msgstr && locales[locale][ctx][message].msgstr[0];
        return result || this.getAlternateContextText(message, locale) || message;
    }
    static getAlternateContextText(message, locale) {
        var _a;
        return ((_a = localesWithoutContext === null || localesWithoutContext === void 0 ? void 0 : localesWithoutContext[locale]) === null || _a === void 0 ? void 0 : _a[message]) || '';
    }
}
module.exports = NerveLocales;
//# sourceMappingURL=locales.js.map